==> pyopenapi_gen-0.8.3.tar.gz: pyopenapi_gen-0.8.3/tests/cli/test_cli_edge_cases.py <==
from pathlib import Path

from typer.testing import CliRunner

from pyopenapi_gen.cli import app

# Minimal spec for code generation
MIN_SPEC = {
    "openapi": "3.1.0",
    "info": {"title": "Edge API", "version": "1.0.0"},
    "paths": {
        "/status": {
            "get": {
                "operationId": "get_status",
                "responses": {"200": {"description": "OK"}},
            }
        }
    },
}


def test_gen_nonexistent_spec_path(tmp_path: Path) -> None:
    """Test calling gen with a spec path that does not exist."""
    runner = CliRunner()
    # Run with catch_exceptions=False to let SystemExit propagate, which pytest handles.
    # Stdout/stderr redirection might be needed if checking stderr content reliably.
    result = runner.invoke(
        app,
        ["gen", str(tmp_path / "nonexistent.json"), "--project-root", str(tmp_path), "--output-package", "client"],
        catch_exceptions=False,  # Let SystemExit propagate
    )
    # We expect SystemExit(1) from _load_spec
    assert result.exit_code == 1, f"Expected exit code 1, got {result.exit_code}. Output: {result.output}"
    # Checking stderr might be unreliable with default invoke, but let's keep it.
    # If this fails intermittently, consider external process call or pytest-subprocess.
    # assert "URL loading not implemented" in result.stderr # Commenting out stderr check for now


def test_gen_with_docs_flag_does_not_break(tmp_path: Path) -> None:
    """Test calling gen with --docs flag results in a Typer usage error."""
    import subprocess
    import sys

    # Create dummy spec
    spec_file = tmp_path / "spec.json"
    spec_file.write_text('{"openapi":"3.1.0","info":{"title":"T","version":"1"},"paths":{}}')

    # Test the CLI using subprocess to avoid Typer testing issues
    result = subprocess.run(
        [
            sys.executable,
            "-m",
            "pyopenapi_gen.cli",
            "gen",
            str(spec_file),
            "--project-root",
            str(tmp_path),
            "--output-package",
            "client",
            "--docs",  # This is an invalid option for the 'gen' command
        ],
        capture_output=True,
        text=True,
    )

    # Check that it fails with non-zero exit code
    assert (
        result.returncode != 0
    ), f"Expected non-zero exit code, got {result.returncode}. Output: {result.stdout}, Error: {result.stderr}"

    # Check for error message indicating invalid option
    error_output = result.stderr
    assert (
        "No such option" in error_output or "Usage:" in error_output or "unrecognized arguments" in error_output
    ), f"Expected error message about invalid option, got: {error_output}"


def test_cli_no_args_shows_help_and_exits_cleanly() -> None:
    """
    Scenario:
        Run the CLI with no arguments.
    Expected Outcome:
        The help message is printed and the exit code is 0 (no error, no 'Missing command').
    """
    import subprocess
    import sys

    # Test the CLI using subprocess to avoid Typer testing issues
    result = subprocess.run(
        [sys.executable, "-m", "pyopenapi_gen.cli"],
        capture_output=True,
        text=True,
    )

    # CLI should show help and exit cleanly (exit code 0)
    assert (
        result.returncode == 0
    ), f"Expected exit code 0, got {result.returncode}. Output: {result.stdout}, Error: {result.stderr}"

    # Check for help content
    output = result.stdout + result.stderr  # Help might go to either stdout or stderr
    assert "Usage:" in output, f"Expected 'Usage:' in output, got: {output}"
    assert (
        "PyOpenAPI Generator CLI" in output or "COMMAND" in output
    ), f"Expected CLI description or COMMAND in output, got: {output}"
    assert "Missing command" not in output, f"Should not have 'Missing command' error, got: {output}"

==> pyopenapi_gen-0.8.8.tar.gz: pyopenapi_gen-0.8.8/tests/cli/test_cli_edge_cases.py <==
from pathlib import Path

from typer.testing import CliRunner

from pyopenapi_gen.cli import app

# Minimal spec for code generation
MIN_SPEC = {
    "openapi": "3.1.0",
    "info": {"title": "Edge API", "version": "1.0.0"},
    "paths": {
        "/status": {
            "get": {
                "operationId": "get_status",
                "responses": {"200": {"description": "OK"}},
            }
        }
    },
}


def test_gen_nonexistent_spec_path(tmp_path: Path) -> None:
    """Test calling gen with a spec path that does not exist."""
    runner = CliRunner()
    # Run with catch_exceptions=False to let SystemExit propagate, which pytest handles.
    # Stdout/stderr redirection might be needed if checking stderr content reliably.
    result = runner.invoke(
        app,
        [str(tmp_path / "nonexistent.json"), "--project-root", str(tmp_path), "--output-package", "client"],
        catch_exceptions=False,  # Let SystemExit propagate
    )
    # We expect SystemExit(1) from _load_spec
    assert result.exit_code == 1, f"Expected exit code 1, got {result.exit_code}. Output: {result.output}"
    # Checking stderr might be unreliable with default invoke, but let's keep it.
    # If this fails intermittently, consider external process call or pytest-subprocess.
    # assert "URL loading not implemented" in result.stderr # Commenting out stderr check for now


def test_gen_with_docs_flag_does_not_break(tmp_path: Path) -> None:
    """Test calling gen with --docs flag results in a Typer usage error."""
    import subprocess
    import sys

    # Create dummy spec
    spec_file = tmp_path / "spec.json"
    spec_file.write_text('{"openapi":"3.1.0","info":{"title":"T","version":"1"},"paths":{}}')

    # Test the CLI using subprocess to avoid Typer testing issues
    result = subprocess.run(
        [
            sys.executable,
            "-m",
            "pyopenapi_gen.cli",
            str(spec_file),
            "--project-root",
            str(tmp_path),
            "--output-package",
            "client",
            "--docs",  # This is an invalid option for the main command
        ],
        capture_output=True,
        text=True,
    )

    # Check that it fails with non-zero exit code
    assert (
        result.returncode != 0
    ), f"Expected non-zero exit code, got {result.returncode}. Output: {result.stdout}, Error: {result.stderr}"

    # Check for error message indicating invalid option
    error_output = result.stderr
    assert (
        "No such option" in error_output or "Usage:" in error_output or "unrecognized arguments" in error_output
    ), f"Expected error message about invalid option, got: {error_output}"


def test_cli_no_args_shows_help_and_exits_cleanly() -> None:
    """
    Scenario:
        Run the CLI with no arguments.
    Expected Outcome:
        The help message is printed and the exit code is 0 (no error, no 'Missing command').
    """
    import subprocess
    import sys

    # Test the CLI using subprocess to avoid Typer testing issues
    result = subprocess.run(
        [sys.executable, "-m", "pyopenapi_gen.cli"],
        capture_output=True,
        text=True,
    )

    # CLI should show missing parameter error and exit with code 2 (Click convention for missing parameters)
    assert (
        result.returncode == 2
    ), f"Expected exit code 2, got {result.returncode}. Output: {result.stdout}, Error: {result.stderr}"

    # Check for help content
    output = result.stdout + result.stderr  # Help might go to either stdout or stderr
    assert "Usage:" in output, f"Expected 'Usage:' in output, got: {output}"
    assert (
        "PyOpenAPI Generator CLI" in output or "Missing argument" in output
    ), f"Expected CLI description or missing argument error in output, got: {output}"
    assert "Missing command" not in output, f"Should not have 'Missing command' error, got: {output}"
